package de.hft.geotime.controllers;

import de.hft.geotime.entities.RecordType;
import de.hft.geotime.entities.TimeRecord;
import de.hft.geotime.entities.TimetrackAccount;
import de.hft.geotime.repositories.RecordRepository;
import de.hft.geotime.repositories.TimetrackAccountRepository;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.Optional;

@RestController
public class RecordController {

    private final RecordRepository recordRepository;
    private final TimetrackAccountRepository accountRepository;

    public RecordController(RecordRepository recordRepository, TimetrackAccountRepository accountRepository) {
        this.recordRepository = recordRepository;
        this.accountRepository = accountRepository;
    }

    @GetMapping("/track")
    public ResponseEntity<TimeRecord> track(@RequestParam String account, Authentication authentication) {
        if (account == null || account.isEmpty()) {
            return new ResponseEntity<>(HttpStatus.BAD_REQUEST);
        }

        TimetrackAccount selectedAccount = accountRepository.findByUser_UsernameAndName(authentication.getName(), account);

        if (selectedAccount == null) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        Page<TimeRecord> entires = recordRepository.findAllByEnddateIsNull(null);
        Optional<TimeRecord> collect = entires.stream()
                .filter(timeRecord -> timeRecord.getAccount().equals(selectedAccount))
                .findFirst();

        if (collect.isPresent()) {
            collect.get().setEnddate(LocalDateTime.now());
            recordRepository.save(collect.get());
            return new ResponseEntity<>(collect.get(), HttpStatus.OK);
        } else {
            TimeRecord newRecord = new TimeRecord();
            newRecord.setType(RecordType.PAID);
            newRecord.setStartdate(LocalDateTime.now());
            newRecord.setAccount(accountRepository.findByUser_UsernameAndName(authentication.getName(), account));
            recordRepository.save(newRecord);
            return new ResponseEntity<>(newRecord, HttpStatus.CREATED);
        }
    }
}
